@@ -5,7 +5,6 @@
 #'@param y The target variable
 #'@param xeq The variables to be used in the equilibrium term of the error correction model
 #'@param xtr The variables to be used in the transient term of the error correction model
-#'@param lags The number of lags to use
 #'@param includeIntercept Boolean whether the y-intercept should be included
 #'@param k The number of models or data partitions desired
 #'@param criterion Whether AIC (default), BIC, or adjustedR2 should be used to select variables
@@ -45,7 +44,7 @@
 #'
 #'@export
 #'@importFrom stats lm complete.cases AIC as.formula drop1
-ecmaveback <- function (y, xeq, xtr, lags=1, includeIntercept = T, criterion = "AIC", k, method = 'boot', seed = 5, weights = NULL, keep = NULL, ...) {
+ecmaveback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", k, method = 'boot', seed = 5, weights = NULL, keep = NULL, ...) {
   if (!is.null(xtr)){
     if (sum(grepl("^delta|Lag[0-9]$", names(xtr))) > 0) {
       warning("You have column name(s) in xtr that begin with 'delta' or end with 'Lag[0-9]'. It is strongly recommended that you change this, otherwise the function 'ecmpredict' may result in errors or incorrect predictions.")
@@ -62,30 +61,30 @@ ecmaveback <- function (y, xeq, xtr, lags=1, includeIntercept = T, criterion = "
     if (!inherits(xeq, "data.frame")) {
       stop("xeq does not inherit class 'data.frame'. See details on how to input them as data frames.")
     }
-    if (nrow(xeq) < (lags+1)) {
+    if (nrow(xeq) < 2) {
       stop("Insufficient data for the lags specified.")
     }
   }
   
   if (!is.null(xeq)){
     xeqnames <- names(xeq)
-    xeqnames <- paste0(xeqnames, paste0("Lag", as.character(lags)))
-    xeq <- data.frame(sapply(xeq, lagpad, lags))
+    xeqnames <- paste0(xeqnames, "Lag1")
+    xeq <- data.frame(sapply(xeq, lagpad))
   }
   
   if (!is.null(xtr)){
     xtrnames <- names(xtr)
     xtrnames <- paste0("delta", xtrnames)
-    xtr <- data.frame(apply(xtr, 2, diff, lags))
+    xtr <- data.frame(apply(xtr, 2, diff))
   }
   
-  if (class(y)=='data.frame'){
+  if (is.data.frame(y)){
     if (ncol(y) > 1){
       warning("You have more than one column in y, only the first will be used")
     }
     y <- y[,1]
   }
-  yLag <- y[1:(length(y) - lags)]
+  yLag <- y[1:(length(y) - 1)]
   
   if (!is.null(xtr) & !is.null(xeq)){
     x <- cbind(xtr, xeq[complete.cases(xeq), ])
@@ -99,8 +98,8 @@ ecmaveback <- function (y, xeq, xtr, lags=1, includeIntercept = T, criterion = "
   }
   
   x <- cbind(x, yLag)
-  names(x) <- c(xnames, paste0("yLag", as.character(lags)))
-  x$dy <- diff(y, lags)
+  names(x) <- c(xnames, "yLag1")
+  x$dy <- diff(y)
   
   if (includeIntercept){
     formula <- "dy ~ ."
