@@ -6,13 +6,12 @@
 #'@return The lagged vector with NA's in missing values
 #'@export
 lagpad <- function(x, k=1) {
+  if (k < 1) {
+    stop("k needs to be 1 or greater")
+  }
+  
   i<-is.vector(x)
-  if(is.vector(x)) x<-matrix(x) else x<-matrix(x,nrow(x))
-  if(k>0) {
-    x <- rbind(matrix(rep(NA, k*ncol(x)),ncol=ncol(x)), matrix(x[1:(nrow(x)-k),], ncol=ncol(x)))
-  }
-  else {
-    x <- rbind(matrix(x[(-k+1):(nrow(x)),], ncol=ncol(x)),matrix(rep(NA, -k*ncol(x)),ncol=ncol(x)))
-  }
+  if(is.vector(x)) x <- matrix(x) else x <- matrix(x, nrow(x))
+  x <- rbind(matrix(rep(NA, k*ncol(x)), ncol=ncol(x)), matrix(x[1:(nrow(x) - k),], ncol = ncol(x)))
   if(i) x[1:length(x)] else x
 }
